@@ -221,7 +221,7 @@ geom_table <- function(mapping = NULL, data = NULL,
                        inherit.aes = FALSE) {
 
   if (!missing(nudge_x) || !missing(nudge_y)) {
-    if (!missing(position)) {
+    if (!missing(position) && position != "identity") {
       rlang::abort("You must specify either `position` or `nudge_x`/`nudge_y`.")
     }
     # We do not keep the original positions if they will not be used
@@ -410,7 +410,8 @@ gtb_draw_panel_fun <-
       }
     }
 
-    grid::grobTree(children = all.grobs, name = "geom.table.panel")
+#    grid::grobTree(children = all.grobs, name = "geom.table.panel")
+    grid::grobTree(children = all.grobs)
 
   }
 
